/*
*  RAL -- Rubrica Addressbook Library
*  file: abook.h
*  
*  Copyright (C) Nicola Fragale <nicolafragale@libero.it>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#ifndef _RUBRICA_ABOOK_H
#define _RUBRICA_ABOOK_H

#include <glib.h>
#include <glib-object.h>

#include "card.h"
#include "error.h"

#define RUBRICA_ABOOK_TYPE            (rubrica_abook_get_type())

#define RUBRICA_ABOOK(obj)            (G_TYPE_CHECK_INSTANCE_CAST((obj), \
                                       RUBRICA_ABOOK_TYPE,               \
                                       RubricaAbook))

#define RUBRICA_ABOOK_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST((klass),  \
                                       RUBRICA_ABOOK_TYPE,               \
                                       RubricaAbookClass))

#define IS_RUBRICA_ABOOK(obj)         (G_TYPE_CHECK_INSTANCE_TYPE((obj), \
                                       RUBRICA_ABOOK_TYPE))

#define IS_RUBRICA_ABOOK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE((klass),  \
                                       RUBRICA_ABOOK_TYPE))

#define RUBRICA_ABOOK_GET_CLASS(klass) (G_TYPE_INSTANCE_GET_CLASS((klass), \
                                        RUBRICA_ABOOK_TYPE,                \
                                        RubricaAbookClass))



typedef struct _RubricaAbook        RubricaAbook;  
typedef struct _RubricaAbookClass   RubricaAbookClass;
typedef struct _RubricaAbookPrivate RubricaAbookPrivate;


struct _RubricaAbook
{
  GObject parent; 
  
  RubricaAbookPrivate *private;
};


struct _RubricaAbookClass
{
  GObjectClass parent_class;
  
  /* methods */
  gboolean (*open_file)           (RubricaAbook* self, gchar* filename);
  gboolean (*save_file)           (RubricaAbook* self, gchar* filename);
  gboolean (*export)              (RubricaAbook* self, gchar* filename);

  /* signals */
  void (*abook_open_fail)         (RubricaAbook*, RubricaError* err);
  void (*abook_save_fail)         (RubricaAbook*, RubricaError* err);
  void (*abook_item_read)         (RubricaAbook*, gpointer data);
  void (*abook_addressbook_read)  (RubricaAbook*);
  void (*abook_addressbook_saved) (RubricaAbook*);
};


GType         rubrica_abook_get_type      (void);


RubricaAbook* rubrica_abook_new           (void);
void          rubrica_abook_free          (RubricaAbook* abook);

gboolean      rubrica_abook_open_file     (RubricaAbook* abook, gchar* name);
gboolean      rubrica_abook_save_file     (RubricaAbook* abook, gchar* name);

RubricaAbook* rubrica_abook_copy          (RubricaAbook* abook);


void          rubrica_abook_set_name      (RubricaAbook* abook, gchar* name);
void          rubrica_abook_set_path      (RubricaAbook* abook, gchar* path);

gchar*        rubrica_abook_get_name      (RubricaAbook* abook);
gchar*        rubrica_abook_get_path      (RubricaAbook* abook);
gint          rubrica_abook_get_items     (RubricaAbook* abook);

void          rubrica_abook_add_card      (RubricaAbook* abook, gpointer card);
void          rubrica_abook_remove_card   (RubricaAbook* abook, gpointer card);
void          rubrica_abook_modify_card   (RubricaAbook* abook, gpointer card);

gpointer      rubrica_abook_get_card       (RubricaAbook* abook);
gpointer      rubrica_abook_get_next_card  (RubricaAbook* abook);
gpointer      rubrica_abook_get_prev_card  (RubricaAbook* abook);

gpointer      rubrica_abook_get_card_by_id (RubricaAbook* abook, gchar* id);

void          rubrica_abook_reset_book     (RubricaAbook* abook);

#endif
