/*
*  RAL -- Rubrica Addressbook Library
*  file: abook_csv.c
*  
*  Copyright (C) Nicola Fragale <nicolafragale@libero.it>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#include <time.h>
#include <glib.h>
#include <glib-object.h>

#include "abook_csv.h"
#include "abook.h"
#include "csv.h"
#include "card.h"
#include "personal.h"
#include "address.h"
#include "contact.h"
#include "groups.h"
#include "net.h"
#include "notes.h"
#include "telephone.h"
#include "work.h"



struct _RubricaAbookCsvPrivate {
  gboolean dispose_has_run;
};


static void rubrica_abook_csv_class_init (RubricaAbookCsvClass* klass);
static void rubrica_abook_csv_init       (RubricaAbookCsv* obj);

static void rubrica_abook_csv_dispose    (RubricaAbookCsv* obj);
static void rubrica_abook_csv_finalize   (RubricaAbookCsv* obj);



static gboolean rubrica_abook_csv_open_file  (RubricaAbookCsv* self, 
					      gchar* filename);
static gboolean rubrica_abook_csv_save_file  (RubricaAbookCsv* self, 
					      gchar* filename);

static void     rubrica_abook_csv_build_card (RubricaCsv* csv, 
					      gpointer card, 
					      gpointer user_data);

static RubricaAbookClass* parent_class = NULL;



GType
rubrica_abook_csv_get_type()
{
  static GType abook_csv_type = 0;
  
  if (!abook_csv_type)
    {
      static const GTypeInfo abook_csv_info =
	{
	  sizeof(RubricaAbookCsvClass),
	  NULL,
	  NULL,
	  (GClassInitFunc) rubrica_abook_csv_class_init,
	  NULL,
	  NULL,
	  sizeof(RubricaAbookCsv),
	  0,
	  (GInstanceInitFunc) rubrica_abook_csv_init
	};

      abook_csv_type = g_type_register_static (RUBRICA_ABOOK_TYPE, 
					       "RubricaAbookCsv",
					       &abook_csv_info, 0);
    }
  
  return abook_csv_type;
}



static void
rubrica_abook_csv_class_init(RubricaAbookCsvClass* klass)
{
  GObjectClass *object_class; 

  object_class = G_OBJECT_CLASS (klass);         /* GObjectClass */
  parent_class = RUBRICA_ABOOK_CLASS (klass);    /* RubricaAbookClass */

  parent_class->open_file = rubrica_abook_csv_open_file;
  parent_class->export    = NULL; /* TODO */

  object_class->dispose  = (GObjectFinalizeFunc) rubrica_abook_csv_dispose;
  object_class->finalize = (GObjectFinalizeFunc) rubrica_abook_csv_finalize;
}



static void
rubrica_abook_csv_init(RubricaAbookCsv* self)
{
  self->private = g_new(RubricaAbookCsvPrivate, 1);
  self->private->dispose_has_run = FALSE;
}



static void 
rubrica_abook_csv_dispose (RubricaAbookCsv* self)
{
  g_return_if_fail(IS_RUBRICA_ABOOK_CSV(self));
  
  if (self->private->dispose_has_run)
    return;

  self->private->dispose_has_run = TRUE;
}



static void 
rubrica_abook_csv_finalize (RubricaAbookCsv* self)
{
  g_return_if_fail(IS_RUBRICA_ABOOK_CSV(self));
  
  g_free(self->private);
  self->private = NULL;
}



static void
rubrica_abook_csv_build_card (RubricaCsv* csv, 
			      gpointer card, 
			      gpointer user_data)
{
  rubrica_abook_add_card(RUBRICA_ABOOK(user_data), card);  
}


static gboolean       
rubrica_abook_csv_open_file (RubricaAbookCsv* self, gchar* filename)
{
  RubricaCsv* csv;
  gint err;

  g_return_val_if_fail(IS_RUBRICA_ABOOK_CSV(self), FALSE); 

  csv = rubrica_csv_new();

  g_signal_connect(G_OBJECT(csv), "card_decoded",
		   G_CALLBACK(rubrica_abook_csv_build_card), self);  

  err = rubrica_csv_open_file(csv, filename);
  
  rubrica_csv_free(csv);
  if (err != FILE_IMPORT_SUCCESS)
    return FALSE;
    
  return TRUE;
}


static gboolean 
rubrica_abook_csv_save_file (RubricaAbookCsv* self, gchar* filename)
{
  return FALSE;
}


/*    Public
*/
RubricaAbookCsv*
rubrica_abook_csv_new(void)
{
  RubricaAbookCsv* self;

  self = g_object_new(rubrica_abook_csv_get_type(), NULL);

  return self;
}


void
rubrica_abook_csv_free(RubricaAbookCsv* self)
{
  g_return_if_fail(IS_RUBRICA_ABOOK_CSV(self));

  g_object_unref(self);   
}

