/*
*  Rubrica
*  file: abook_vcard.c
*  
*  Copyright (C) Nicola Fragale <nicolafragale@libero.it>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#include <time.h>
#include <glib.h>
#include <glib-object.h>

#include "abook_vcard.h"
#include "vcard.h"
#include "card.h"
#include "personal.h"
#include "address.h"
#include "contact.h"
#include "groups.h"
#include "net.h"
#include "notes.h"
#include "telephone.h"
#include "work.h"



struct _RubricaAbookVCardPrivate {
  gboolean dispose_has_run;
};


static void rubrica_abook_vcard_class_init (RubricaAbookVCardClass* klass);
static void rubrica_abook_vcard_init       (RubricaAbookVCard* obj);

static void rubrica_abook_vcard_dispose    (RubricaAbookVCard* obj);
static void rubrica_abook_vcard_finalize   (RubricaAbookVCard* obj);



static gboolean rubrica_abook_vcard_open_file  (RubricaAbookVCard* self, 
						gchar* filename);
static gboolean rubrica_abook_vcard_save_file  (RubricaAbookVCard* self, 
						gchar* filename);

static void     rubrica_abook_vcard_build_card (RubricaVCard* vcard, 
						gpointer card,
						gpointer user_data);

static RubricaAbookClass* parent_class = NULL;


GType
rubrica_abook_vcard_get_type()
{
  static GType abook_vcard_type = 0;
  
  if (!abook_vcard_type)
    {
      static const GTypeInfo abook_vcard_info =
	{
	  sizeof(RubricaAbookVCardClass),
	  NULL,
	  NULL,
	  (GClassInitFunc) rubrica_abook_vcard_class_init,
	  NULL,
	  NULL,
	  sizeof(RubricaAbookVCard),
	  0,
	  (GInstanceInitFunc) rubrica_abook_vcard_init
	};

      abook_vcard_type = g_type_register_static (RUBRICA_ABOOK_TYPE, 
						 "RubricaAbookVCard",
						 &abook_vcard_info, 0);
    }
  
  return abook_vcard_type;
}



static void
rubrica_abook_vcard_class_init(RubricaAbookVCardClass* klass)
{
  GObjectClass *object_class; 

  object_class = G_OBJECT_CLASS (klass);         /* GObjectClass */
  parent_class = RUBRICA_ABOOK_CLASS (klass);    /* RubricaAbookClass */

  parent_class->open_file = rubrica_abook_vcard_open_file;
  parent_class->export    = rubrica_abook_vcard_save_file;

  object_class->dispose  = (GObjectFinalizeFunc) rubrica_abook_vcard_dispose;
  object_class->finalize = (GObjectFinalizeFunc) rubrica_abook_vcard_finalize;
}



static void
rubrica_abook_vcard_init(RubricaAbookVCard* self)
{
  self->private = g_new(RubricaAbookVCardPrivate, 1);
  self->private->dispose_has_run = FALSE;
}



static void 
rubrica_abook_vcard_dispose (RubricaAbookVCard* self)
{
  g_return_if_fail(IS_RUBRICA_ABOOK_VCARD(self));
  
  if (self->private->dispose_has_run)
    return;

  self->private->dispose_has_run = TRUE;
}



static void 
rubrica_abook_vcard_finalize (RubricaAbookVCard* self)
{
  g_return_if_fail(IS_RUBRICA_ABOOK_VCARD(self));
  
  g_free(self->private);
  self->private = NULL;
}



static void
rubrica_abook_vcard_build_card (RubricaVCard* vcard, 
				gpointer card,
				gpointer addressbook)
{
  rubrica_abook_add_card(RUBRICA_ABOOK(addressbook), card);  
}



static gboolean       
rubrica_abook_vcard_open_file (RubricaAbookVCard* self, gchar* filename)
{
  RubricaVCard* vcard;
  gint err;

  g_return_val_if_fail(IS_RUBRICA_ABOOK_VCARD(self), FALSE); 

  vcard = rubrica_vcard_new();

  g_signal_connect(G_OBJECT(vcard), "card_decoded",
		   G_CALLBACK(rubrica_abook_vcard_build_card), self);  

  err = rubrica_vcard_open_file(vcard, filename);

  rubrica_vcard_free_vcard(vcard);
  if (err == RUBRICA_VCARD_FILE_OPEN_FAIL)
    return FALSE;
    
  return TRUE;
}


static gboolean 
rubrica_abook_vcard_save_file  (RubricaAbookVCard* self, gchar* filename)
{

  return FALSE;
}



/*    Public
*/
RubricaAbookVCard*
rubrica_abook_vcard_new(void)
{
  RubricaAbookVCard* self;

  self = g_object_new(rubrica_abook_vcard_get_type(), NULL);

  return self;
}


void
rubrica_abook_vcard_free(RubricaAbookVCard* self)
{
  g_return_if_fail(IS_RUBRICA_ABOOK_VCARD(self));

  g_object_unref(self);   
}

