/*
*  RAL -- Rubrica Addressbook Library
*  file: company.h
*  
*  Copyright (C) Nicola Fragale <nicolafragale@libero.it>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#ifndef _RUBRICA_COMPANY_H
#define _RUBRICA_COMPANY_H

#include <glib.h>
#include <glib-object.h>

#include "card.h"
#include "ref.h"


#define RUBRICA_COMPANY_CARD_TYPE          (rubrica_company_card_get_type())

#define RUBRICA_COMPANY_CARD(obj)          (G_TYPE_CHECK_INSTANCE_CAST((obj), \
                                            RUBRICA_COMPANY_CARD_TYPE,        \
                                            RubricaCompanyCard))

#define RUBRICA_COMPANY_CARD_CLASS(klass)  (G_TYPE_CHECK_CLASS_CAST((klass),  \
                                            RUBRICA_COMPANY_CARD_TYPE,        \
                                            RubricaCompanyCardClass))

#define IS_RUBRICA_COMPANY_CARD(obj)       (G_TYPE_CHECK_INSTANCE_TYPE((obj), \
                                            RUBRICA_COMPANY_CARD_TYPE))

#define IS_RUBRICA_COMPANY_CARD_CLASS(kls) (G_TYPE_CHECK_CLASS_TYPE((kls),   \
                                            RUBRICA_COMPANY_CARD_TYPE))

#define RUBRICA_COMPANY_CARD_GET_CLASS(kls) (G_TYPE_INSTANCE_GET_CLASS((kls),\
                                             RUBRICA_COMPANY_CARD_TYPE,      \
                                             RubricaCompanyCardClass))


typedef struct _RubricaCompanyCard        RubricaCompanyCard;
typedef struct _RubricaCompanyCardClass   RubricaCompanyCardClass;
typedef struct _RubricaCompanyCardPrivate RubricaCompanyCardPrivate;



struct _RubricaCompanyCard
{
  RubricaCard parent;

  gchar* company_name;
  gchar* pi;                /* partita iva | codice fiscale */ 
  gchar* notes;                 
  
  RubricaCompanyCardPrivate* private;
};


struct _RubricaCompanyCardClass
{
  RubricaCardClass parent;
};



GType rubrica_company_card_get_type (void);


RubricaCompanyCard* rubrica_company_card_new (void);


void   rubrica_company_card_set              (RubricaCompanyCard* card, 
					      gchar* name, gchar* pi, 
					      gchar* notes);

void   rubrica_company_card_set_company_name (RubricaCompanyCard* card,
					      gchar* name);
void   rubrica_company_card_set_pi           (RubricaCompanyCard* card, 
					      gchar* pi);
void   rubrica_company_card_set_notes        (RubricaCompanyCard* card,
					      gchar* notes);


void   rubrica_company_card_get              (RubricaCompanyCard* card, 
					      gchar** name, gchar** pi, 
					      gchar** notes);

gchar* rubrica_company_card_get_company_name (RubricaCompanyCard* card);
gchar* rubrica_company_card_get_pi           (RubricaCompanyCard* card);
gchar* rubrica_company_card_get_notes        (RubricaCompanyCard* card);



void rubrica_company_card_add_ref (RubricaCompanyCard* card, RubricaRef* ref);
void rubrica_company_card_del_ref (RubricaCompanyCard* card, RubricaRef* ref);

gpointer rubrica_company_card_get_ref      (RubricaCompanyCard* card);
gpointer rubrica_company_card_get_next_ref (RubricaCompanyCard* card);
gpointer rubrica_company_card_get_prev_ref (RubricaCompanyCard* card);
void     rubrica_company_card_reset_ref    (RubricaCompanyCard* card);

#endif
