/*
*  RAL -- Rubrica Addressbook Library
*  file: contact.h
*  
*  Copyright (C) Nicola Fragale <nicolafragale@libero.it>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#ifndef _RUBRICA_CONTACT_H
#define _RUBRICA_CONTACT_H

#include <glib.h>
#include <glib-object.h>

#include "utils.h"
#include "date.h"


#define RUBRICA_CONTACT_TYPE            (rubrica_contact_get_type())

#define RUBRICA_CONTACT(obj)            (G_TYPE_CHECK_INSTANCE_CAST((obj),  \
                                         RUBRICA_CONTACT_TYPE,              \
                                         RubricaContact))

#define RUBRICA_CONTACT_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST((klass),   \
                                         RUBRICA_CONTACT_TYPE,              \
                                         RubricaContactClass))

#define IS_RUBRICA_CONTACT(obj)         (G_TYPE_CHECK_INSTANCE_TYPE((obj),  \
                                         RUBRICA_CONTACT_TYPE))

#define IS_RUBRICA_CONTACT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE((klass),   \
                                         RUBRICA_CONTACT_TYPE))

#define RUBRICA_CONTACT_GET_CLASS(klass) (G_TYPE_INSTANCE_GET_CLASS((klass), \
                                          RUBRICA_CONTACT_TYPE,              \
                                          RubricaContactClass))



typedef struct _RubricaContact        RubricaContact;
typedef struct _RubricaContactClass   RubricaContactClass;
typedef struct _RubricaContactPrivate RubricaContactPrivate;


/* Contact contact data 
*/
struct _RubricaContact
{
  GObject parent;

  gchar*   first;          /* first name  */
  gchar*   middle;         /* middle name */
  gchar*   last;           /* last name   */
  gchar*   nick;           /* nick name   */

  gchar*   prof;           /* profession  */
  gchar*   prefix;         /* prefix      */ 
  gchar*   title;          /* title       */

  RubricaDate* birthday;   /* */

  gchar*   photo;          /* contact's photo (uri) */

  RubricaContactPrivate* private;
};


struct _RubricaContactClass {
  GObjectClass parent;
};


GType rubrica_contact_get_type       (void);


RubricaContact* rubrica_contact_new  (void);
void            rubrica_contact_free (RubricaContact* contact);

RubricaContact* rubrica_contact_copy (RubricaContact* contact);

void rubrica_contact_set             (RubricaContact* contact, gchar* first,
				      gchar* middle, gchar* last, gchar* nick,
				      gchar* prof, gchar* prefix, gchar* title,
				      gchar* photo, time_t birth);

void rubrica_contact_set_first_name  (RubricaContact* contact, gchar* first);
void rubrica_contact_set_middle_name (RubricaContact* contact, gchar* middle);
void rubrica_contact_set_last_name   (RubricaContact* contact, gchar* last);
void rubrica_contact_set_nick_name   (RubricaContact* contact, gchar* nick);

void rubrica_contact_set_profession  (RubricaContact* contact, gchar* prof);
void rubrica_contact_set_prefix      (RubricaContact* contact, gchar* prefix);
void rubrica_contact_set_title       (RubricaContact* contact, gchar* title);
void rubrica_contact_set_photo       (RubricaContact* contact, gchar* photo);
void rubrica_contact_set_birthday    (RubricaContact* contact, time_t birth);


void   rubrica_contact_get             (RubricaContact* contact, gchar** first,
					gchar** middle, gchar** last, 
					gchar** nick, gchar** prof, 
					gchar** prefix, gchar** title, 
					gchar** photo, gchar** day, 
					gchar** month, gchar** year);
gchar* rubrica_contact_get_first_name  (RubricaContact* contact);
gchar* rubrica_contact_get_middle_name (RubricaContact* contact);
gchar* rubrica_contact_get_last_name   (RubricaContact* contact);
gchar* rubrica_contact_get_nick_name   (RubricaContact* contact);

gchar* rubrica_contact_get_profession  (RubricaContact* contact);
gchar* rubrica_contact_get_prefix      (RubricaContact* contact);
gchar* rubrica_contact_get_title       (RubricaContact* contact);
gchar* rubrica_contact_get_photo       (RubricaContact* contact);

gchar* rubrica_contact_get_birth_day   (RubricaContact* contact);
gchar* rubrica_contact_get_birth_month (RubricaContact* contact);
gchar* rubrica_contact_get_birth_year  (RubricaContact* contact);
time_t rubrica_contact_get_birthdate   (RubricaContact* contact);



#endif
