/*
*  RAL -- Rubrica Addressbook Library
*  file: csv.h
*  
*  Copyright (C) Nicola Fragale <nicolafragale@libero.it>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#ifndef _RUBRICA_CSV_H
#define _RUBRICA_CSV_H

#include <stdio.h>
#include <glib.h>
#include <glib-object.h>

#include "error.h"

#define RUBRICA_CSV_TYPE            (rubrica_csv_get_type())

#define RUBRICA_CSV(obj)            (G_TYPE_CHECK_INSTANCE_CAST((obj),  \
                                     RUBRICA_CSV_TYPE, RubricaCsv))

#define RUBRICA_CSV_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST((klass),   \
                                     RUBRICA_CSV_TYPE, RubricaCsvClass))

#define IS_RUBRICA_CSV(obj)         (G_TYPE_CHECK_INSTANCE_TYPE((obj),  \
				     RUBRICA_CSV_TYPE))

#define IS_RUBRICA_CSV_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE((klass),   \
                                     RUBRICA_CSV_TYPE))

#define RUBRICA_CSV_GET_CLASS(obj)  (G_TYPE_CHECK_INSTANCE_GET_CLASS((obj), \
                                     RUBRICA_CSV_TYPE, RubricaCsvClass))


typedef struct _RubricaCsv          RubricaCsv;
typedef struct _RubricaCsvClass     RubricaCsvClass;
typedef struct _RubricaCsvPrivate   RubricaCsvPrivate;


struct _RubricaCsv 
{
  GObject parent;
  
  FILE* fp;                       /* the csv file */

  /* private */
  RubricaCsvPrivate* private;
};


struct _RubricaCsvClass
{
  GObjectClass parent;
  
  /* signals */
  void (*csv_file_opened)         (RubricaCsv* self, RubricaError err);
  void (*csv_card_decoded)        (RubricaCsv* self, gpointer card);
  void (*csv_addressbook_decoded) (RubricaCsv* self);
};


GType       rubrica_csv_get_type   (void);


/* ************ Public ************
*/

RubricaCsv* rubrica_csv_new                  (void);
void        rubrica_csv_free                 (RubricaCsv *self);

gint        rubrica_csv_open_file            (RubricaCsv* self, 
					      gchar* filename);
void        rubrica_csv_read_previous_record (RubricaCsv *self);

/*
gchar*      rubrica_csv_get_data            (RubricaCsv* csv, 
                                             RubricaCsvField field);
*/


#endif  /* _RUBRICA_CSV_H */ 
