/*
*  RAL -- Rubrica Addressbook Library
*  file: io.h
*  
*  Copyright (C) Nicola Fragale <nicolafragale@libero.it>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#ifndef _RUBRICA_IO_H
#define _RUBRICA_IO_H

#include <glib.h>
#include <libxml/tree.h>

#include "error.h"


void rubrica_io_set_str  (xmlNodePtr node, gchar *label, gchar* string);
void rubrica_io_set_bool (xmlNodePtr node, gchar *label, gboolean bool);
void rubrica_io_set_num  (xmlNodePtr node, gchar *label, gulong val);
void rubrica_io_set_date (xmlNodePtr node, gboolean bool, time_t date);

#define rubrica_io_set_time(node, lbl, val) rubrica_io_set_num(node, lbl, val)


gchar*   rubrica_io_get               (xmlNodePtr node, xmlChar* name, 
				       RubricaError* e);
gchar*   rubrica_io_get_content       (xmlNodePtr node, RubricaError* err);
gboolean rubrica_io_get_bool          (xmlNodePtr node, gchar* key,
				       RubricaError* err);
glong    rubrica_io_get_date          (xmlNodePtr node, gchar* key, 
				       RubricaError* err); 
time_t   rubrica_io_get_calendar      (xmlNodePtr node, 
				       gchar** day, gchar** month, 
				       gchar** year, RubricaError *err);

gchar*   rubrica_io_get_prop          (xmlNodePtr node, gchar* key, 
				       RubricaError *err);
gchar*   rubrica_io_get_prop_from     (xmlNodePtr node, gchar* node_name,
				       gchar* key, RubricaError* err);  

gboolean rubrica_io_get_bool_from     (xmlNodePtr node, gchar* node_name,
				       gchar* key, RubricaError* err);

time_t   rubrica_io_get_calendar_from (xmlNodePtr node, gchar* node_name,
				       gchar** day, gchar** month, 
				       gchar** year, RubricaError *err);


xmlNodePtr rubrica_io_get_node        (xmlNodePtr node, xmlChar* key);

#endif
