/*
*  RAL -- Rubrica Addressbook Library
*  file: notes.h
*  
*  Copyright (C) Nicola Fragale <nicolafragale@libero.it>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#ifndef _RUBRICA_NOTES_H
#define _RUBRICA_NOTES_H

#include <time.h>
#include <glib.h>
#include <glib-object.h>

#include "date.h"

#define RUBRICA_NOTES_TYPE             (rubrica_notes_get_type())

#define RUBRICA_NOTES(obj)             (G_TYPE_CHECK_INSTANCE_CAST((obj), \
                                        RUBRICA_NOTES_TYPE,               \
                                        RubricaNotes))

#define RUBRICA_NOTES_CLASS(klass)     (G_TYPE_CHECK_CLASS_CAST((klass),  \
                                        RUBRICA_NOTES_TYPE,               \
                                        RubricaNotesClass))

#define IS_RUBRICA_NOTES(obj)          (G_TYPE_CHECK_INSTANCE_TYPE((obj), \
                                        RUBRICA_NOTES_TYPE))

#define IS_RUBRICA_NOTES_CLASS(klass)  (G_TYPE_CHECK_CLASS_TYPE((klass),  \
                                        RUBRICA_NOTES_TYPE))

#define RUBRICA_NOTES_GET_CLASS(klass) (G_TYPE_INSTANCE_GET_CLASS((kls),  \
                                        RUBRICA_NOTES_TYPE,               \
                                        RubricaNotesClass))



typedef struct _RubricaNotes        RubricaNotes; 
typedef struct _RubricaNotesClass   RubricaNotesClass;
typedef struct _RubricaNotesPrivate RubricaNotesPrivate;


struct _RubricaNotes
{
  GObject parent;

  gboolean married;      /* is contact married?          */

  gchar* spouse;         /* spouse name                  */
  gchar* children;       /* children notes               */
  gchar* notes;          /* other notes                  */
  gchar* pubkey;         /* public key                   */

  RubricaDate* birthday;
  RubricaDate* anniversary;
  
  RubricaNotesPrivate* private;
};


struct _RubricaNotesClass
{
  GObjectClass parent_class;
};


GType         rubrica_notes_get_type (void);
 

RubricaNotes* rubrica_notes_new  (void);
void          rubrica_notes_free (RubricaNotes* notes);

RubricaNotes* rubrica_notes_copy (RubricaNotes* notes);

/*    set
*/
void rubrica_notes_set (RubricaNotes* notes, gboolean is_married,
			gboolean know_birtday, gboolean know_anniversary,
			gchar* name, gchar* cnote, gchar* onote, 
			gchar* pubkey, time_t birth, time_t anniversary);

void rubrica_notes_set_married          (RubricaNotes* notes, 
					 gboolean is_married);
void rubrica_notes_set_know_birthday    (RubricaNotes* notes, gboolean know);
void rubrica_notes_set_know_anniversary (RubricaNotes* notes, gboolean know);

void rubrica_notes_set_spouse_name      (RubricaNotes* notes, gchar* name);
void rubrica_notes_set_children_notes   (RubricaNotes* notes, gchar* cnote);
void rubrica_notes_set_other_notes      (RubricaNotes* notes, gchar* onote);
void rubrica_notes_set_public_key       (RubricaNotes* notes, gchar* pubkey);

void rubrica_notes_set_birthday         (RubricaNotes* notes, time_t birth);
void rubrica_notes_set_anniversary      (RubricaNotes* notes, 
					 time_t anniversary);


/*    get
 */
void rubrica_notes_get (RubricaNotes* notes,
			gboolean* married, gboolean* birth, gboolean *ann,
			gchar** spouse, gchar** children, 
			gchar** note, gchar** pkey,
			gchar** bday, gchar** bmonth, gchar** byear, 
			gchar** aday, gchar** amonth, gchar** ayear);


gboolean rubrica_notes_is_married            (RubricaNotes* notes);
gboolean rubrica_notes_known_birthday        (RubricaNotes* notes);
gboolean rubrica_notes_know_anniversary      (RubricaNotes* notes);

gchar*   rubrica_notes_get_spouse_name       (RubricaNotes* notes);
gchar*   rubrica_notes_get_children_notes    (RubricaNotes* notes);
gchar*   rubrica_notes_get_other_notes       (RubricaNotes* notes);
gchar*   rubrica_notes_get_public_key        (RubricaNotes* notes);

gchar*   rubrica_notes_get_birth_day         (RubricaNotes* notes);
gchar*   rubrica_notes_get_birth_month       (RubricaNotes* notes);
gchar*   rubrica_notes_get_birth_year        (RubricaNotes* notes);

gchar*   rubrica_notes_get_anniversary_day   (RubricaNotes* notes);
gchar*   rubrica_notes_get_anniversary_month (RubricaNotes* notes);
gchar*   rubrica_notes_get_anniversary_year  (RubricaNotes* notes);

time_t   rubrica_notes_get_birthdate         (RubricaNotes* notes);
time_t   rubrica_notes_get_anniversarydate   (RubricaNotes* notes);


void     rubrica_notes_append_other_notes    (RubricaNotes* notes, 
					      gchar* onote);
#endif
