/*
*  RAL -- Rubrica Addressbook Library
*  file: ref.c
*  
*  Copyright (C) Nicola Fragale <nicolafragale@libero.it>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#include <glib.h>
#include <glib-object.h>

#include "ref.h"
#include "utils.h"

/*
enum {
  RUBRICA_REF_ID   = 1,
  RUBRICA_REF_NAME = 2
};
*/


struct _RubricaRefPrivate {
  gchar* id;          /* card id     */  /* reference to other cards, that */
  gchar* info;        /* card's info */  /* are in relation whith this one */

  gchar* reserved1;   /* may be used in future */                
  gchar* reserved2;                  
  gchar* reserved3;          

  gboolean dispose_has_run;
};



static void rubrica_ref_class_init (RubricaRefClass* klass);
static void rubrica_ref_init       (RubricaRef* obj);

static void rubrica_ref_dispose    (RubricaRef* obj);
static void rubrica_ref_finalize   (RubricaRef* obj);

/*
static void rubrica_ref_set_property (GObject* obj, guint property_id,
				      const GValue* value, GParamSpec* spec);
static void rubrica_ref_get_property (GObject* obj, guint property_id,
				      GValue* value, GParamSpec* spec);
*/



GType
rubrica_ref_get_type()
{
  static GType rubrica_ref_type = 0;
  
  if (!rubrica_ref_type)
    {
      static const GTypeInfo rubrica_ref_info =
	{
	  sizeof(RubricaRefClass),
	  NULL,
	  NULL,
	  (GClassInitFunc) rubrica_ref_class_init,
	  NULL,
	  NULL,
	  sizeof(RubricaRef),
	  0,
	  (GInstanceInitFunc) rubrica_ref_init
	};

      rubrica_ref_type = g_type_register_static (G_TYPE_OBJECT, 
						 "RubricaRef",
						 &rubrica_ref_info, 0);
    }
  
  return rubrica_ref_type;
}


static void
rubrica_ref_class_init(RubricaRefClass* klass)
{
  GObjectClass *parent_class;
  //  GParamSpec* pspec;
  
  parent_class  = G_OBJECT_CLASS (klass);

  parent_class->dispose      = (GObjectFinalizeFunc) rubrica_ref_dispose;
  parent_class->finalize     = (GObjectFinalizeFunc) rubrica_ref_finalize;

  //  parent_class->set_property = rubrica_ref_set_property;
  //  parent_class->get_property = rubrica_ref_get_property;

  /* class property 
  pspec = g_param_spec_string("id",
			      "card id",
			      "the id of the related card", 
			      NULL,   
			      G_PARAM_CONSTRUCT | G_PARAM_READABLE);
  g_object_class_install_property(parent_class, RUBRICA_REF_ID, pspec); 
  
  pspec = g_param_spec_string("info",
			      "card infos",
			      "the infos related to the card",
			      NULL, 
			      G_PARAM_READWRITE); 
  g_object_class_install_property(parent_class, RUBRICA_REF_NAME, pspec);  
  */
}


static void
rubrica_ref_init(RubricaRef* self)
{
  self->private = g_new(RubricaRefPrivate, 1);

  self->private->id   = NULL;
  self->private->info = NULL;

  self->private->reserved1 = NULL;
  self->private->reserved2 = NULL;
  self->private->reserved3 = NULL;

  self->private->dispose_has_run = FALSE;
}

 
/*
static void 
rubrica_ref_set_property (GObject* obj, guint property_id,
			  const GValue* value, GParamSpec* spec)
{
  RubricaRef* self = (RubricaRef*) obj;

  switch (property_id) 
    {
    case RUBRICA_REF_ID:
      g_free(self->private->id);
      self->private->id = g_value_dup_string(value);
      break; 

    case RUBRICA_REF_NAME:
      g_free(self->private->info);
      self->private->info = g_value_dup_string(value);
      break; 
      
    default: 
      break; 
    } 
} 
 

static void 
rubrica_ref_get_property (GObject* obj, guint property_id,
			  GValue* value, GParamSpec* spec)
{
  RubricaRef* self = (RubricaRef*) obj;

  switch (property_id) 
    {
    case RUBRICA_REF_ID:
      g_value_set_string(value, self->private->id);
      break; 
      
    case RUBRICA_REF_NAME:
      g_value_set_string(value, self->private->info);
      break; 
      
    default:
      break;  
    }  
}

*/

static void 
rubrica_ref_dispose (RubricaRef* self)
{
  g_return_if_fail(IS_RUBRICA_REF(self));
  
  if (self->private->dispose_has_run)
    return;

  self->private->dispose_has_run = TRUE;
}


static void 
rubrica_ref_finalize (RubricaRef* self)
{
  g_return_if_fail(IS_RUBRICA_REF(self));
  
  rubrica_utils_free_string(self->private->id);
  rubrica_utils_free_string(self->private->info);
  
  g_free(self->private);
  self->private = NULL;
}



/*   Public
*/
RubricaRef*
rubrica_ref_new(void)
{
  RubricaRef* self;

  self = g_object_new(rubrica_ref_get_type(), NULL);
  
  return self;
}


RubricaRef*
rubrica_ref_with_id_new(gchar* id)
{
  RubricaRef* self;

  self = g_object_new(rubrica_ref_get_type(), NULL);

  rubrica_ref_set_id(self, id);  

  return self;
}


void
rubrica_ref_free(RubricaRef* self)
{
  g_return_if_fail(IS_RUBRICA_REF(self));

  g_object_unref(self);   
}




void 
rubrica_ref_set_id(RubricaRef* self, gchar* id)
{
  g_return_if_fail(IS_RUBRICA_REF(self));

  rubrica_utils_free_string(self->private->id);
  self->private->id = g_strdup(id);
}


void 
rubrica_ref_set_info(RubricaRef* self, gchar* info)
{
  g_return_if_fail(IS_RUBRICA_REF(self));

  rubrica_utils_free_string(self->private->info);
  self->private->info = g_strdup(info);  
}



gchar*
rubrica_ref_get_id(RubricaRef* self)
{
  g_return_val_if_fail(IS_RUBRICA_REF(self), NULL);
  
  return self->private->id;
}


gchar*
rubrica_ref_get_info(RubricaRef* self)
{
  g_return_val_if_fail(IS_RUBRICA_REF(self), NULL);

  return self->private->info;
}


RubricaRef* 
rubrica_ref_copy (RubricaRef* self)
{
  RubricaRef* new;

  g_return_val_if_fail(IS_RUBRICA_REF(self), NULL);

  new = rubrica_ref_with_id_new(rubrica_ref_get_id(self));
  
  rubrica_ref_set_info(new, rubrica_ref_get_info(self));

  return new;
}

/*
void 
rubrica_ref_set(RubricaRef* self, const gchar* property, gchar* val)
{
  
  GValue* value;

  g_value_init(value, G_TYPE_STRING);
  g_value_set_string(value, val);
  

  g_object_set(G_OBJECT(self), property, val);  
} 
*/
