/*
*  RAL -- Rubrica Addressbook Library
*  file: save.c
*  
*  Copyright (C) Nicola Fragale <nicolafragale@libero.it>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#include <glib.h>
#include <libxml/tree.h>

#include "save.h"
#include "card.h"
#include "personal.h"
#include "company.h"
#include "contact.h"
#include "address.h"
#include "groups.h"
#include "net.h"
#include "notes.h"
#include "telephone.h"
#include "ref.h"
#include "io.h"
#include "error.h"


/*
  RubricaDoc file structure:
     version:    rubrica's version that made the addressbook file
     fileformat: #4
     doctype:    addressbook

  <?xml version="1.0" encoding="UTF-8"?>
  <Rubrica version="" fileformat="" doctype="">        root
     <Card                                             root child 
            name=""                                    the card name
            deletable=""                               is a deletable card?
            deleted=""                                 was card deleted?
            rank=""                                    card rank (1..5)
            id="pcxxx"                                 card id   (es:  pc643)
	    created=""                                 creation date
            last_change=""                             last change date
	    type="">                                   card's type 
         <Groups>                                      card child 
             <Group>...................</Group>        groups children
	     ...
         </Groups>       
	 <Addresses>                                   card child
             <Address type="">                         addresses children
                 <Street number="">....</Street>       address child
	         <City zip="">.........</City>
	         <Province>............</Province>
	         <State>...............</State>
	         <Country>.............</Country>
 	      </Address>
	     ...
         </Addresses>
	 <Net>
	     <Uri type="web">..........</Uri>
	     <Uri type="email">........</Uri>
	     <Uri type="aim">..........</Uri>
	     <Uri type="msn">..........</Uri>
	     <Uri type="yahoo">........</Uri>
	     <Uri type="icq">..........</Uri>
	     <Uri type="jabber">.......</Uri>	     
	     ...
	 </Net>
	 <TelephoneNumbers>
	     <Telephone type="home">...</Telephone>
	     <Telephone type="work">...</Telephone>
	     <Telephone type="fax">....</Telephone>
	     ...
 	 </TelephoneNumbers>
         <Data>                                        card child
             <FirstName>...............</FirstName>    data child 
	     <MiddleName>..............</MiddleName>     "    "
	     <LastName>................</LastName>                    
	     <Nickname>................</NickName>                    
	     <Profession>..............</Profession>                  
 	     <NamePrefix>..............</NamePrefix>                  
	     <Title>...................</Title>                       
	     <Photo type="">...........</Photo>
	     <Birthday known="" day="" month="" year=""/>  
         </Data>
	 <Work>
	     <Assigment>...............</Assigment>
	     <Organization>............</Organization>
             <Department>..............</Department>
	     <SubDepartment>...........</SubDepartment>
	     <ManagerName>.............</ManagerName>
	     <ManagerPhone>............</ManagerPhone>
	     <CollabratorName>.........</CollabratorName>
	     <CollaboratorPhone>.......</CollabratorPhone>
         </Work>
	 <Notes married="">
             <SpouseName>..............</SpouseName>
	     <Child>...................</Child>
	     <OtherNotes>..............</OtherNotes>
	     <PublicKey>...............</PublicKey>
	     <SpouseBirthday known="" day="" month="" year=""/>
	     <Anniversary known="" day="" month="" year""/>
         </Notes>
     </Card>
     <Card>
     <Card                                             root child 
            name=""                                    the card name
            deletable=""                               is a deletable card?
            deleted=""                                 was card deleted?
            rank=""                                    card rank (1..5)
            id="ccxxx"                                 card id   (es: cc1039)
	    created=""                                 creation date
            last_change=""                             last change date
	    type="company">                            card's type 
         <Groups>                                      card child 
             <Group>...................</Group>        groups children
	     ...
         </Groups>       
	 <Addresses>                                   card child
             <Address type="">                         addresses children
                 <Street number="">....</Street>       address child
	         <City zip="">.........</City>
	         <Province>............</Province>
	         <State>...............</State>
	         <Country>.............</Country>
 	      </Address>
	     ...
         </Addresses>
	 <Net>
	     <Uri type="web">..........</Uri>
	     <Uri type="email">........</Uri> 
	     ...
	 </Net>
	 <TelephoneNumbers>
	     <Telephone type="green">......</Telephone>
	     <Telephone type="operator">...</Telephone>
	     <Telephone type="fax">........</Telephone>
	     ...
 	 </TelephoneNumbers>
         <Company>
             <CompanyName>.............</CompanyName>
	     <Pi>......................</Pi>
	     <Notes>...................</Notes>
	     <Refs>
	        <Ref refid="">.........</Ref>
		....
	     </Refs>
         </Company>
	 <CompanyContacts>
	     <Contact ref_id="id_personal">Nome Cognome</Contact>
	     ...
	 <CompanyContacts>
     </Card>
     ...
  </Rubrica>


  Rubrica
     |
     | children
     |
     v   next         next         next 
   Card-------->Card-------->....------->Card
     |
     | children
     |
     v   next                
   Groups--->Data--->Addresses--->Net--->....Phone-->Work-->Notes
     |        \          |         |           |        |      |      
     | child  | child    | child   |           |        |      |     
     |        |          v         v           v        v      v     
     |        |         ...       ...         ...      ...     ...    ...   
     v        v
   Group    FirstName--->MiddleName--->...

   pcxxx => personal card xxx
   ccxxx => company  card xxx
*/



void
rubrica_save_write_card(xmlNodePtr cardxml, RubricaCard *card)
{
  xmlNodePtr groupxml;    /* group node                     */
  xmlNodePtr addressxml;  /* addresses node, address father */ 
  xmlNodePtr netxml;
  xmlNodePtr telxml;
  gpointer data;

  /* setto le proprietà della scheda 
     nome, editabile, concellabile
  */
  rubrica_io_set_str (cardxml, "name", rubrica_card_get_card_name(card));
  rubrica_io_set_bool(cardxml, "deletable", rubrica_card_is_deletable(card));
  rubrica_io_set_bool(cardxml, "deleted", rubrica_card_is_deleted(card)); 
  rubrica_io_set_num (cardxml, "rank", rubrica_card_get_rank(card));
  rubrica_io_set_str (cardxml, "id", rubrica_card_get_id(card));
  rubrica_io_set_str (cardxml, "type", rubrica_card_get_card_type(card));
  rubrica_io_set_time(cardxml, "created", 
		      rubrica_card_get_creation_time(card));
  rubrica_io_set_time(cardxml, "last_change", 
		      rubrica_card_get_modification_time(card));
   
  /* Groups
   */
  groupxml = xmlNewTextChild(cardxml, NULL, "Groups", NULL);
  data = rubrica_card_get_group(RUBRICA_CARD(card));
  for (; data; data = rubrica_card_get_next_group(RUBRICA_CARD(card)))
    xmlNewTextChild(groupxml, NULL, "Group", (xmlChar*) data);
	
  
  /* Addresses
   */
  addressxml = xmlNewTextChild(cardxml, NULL, "Addresses", NULL);
  data = rubrica_card_get_address(RUBRICA_CARD(card));
  for (; data; data = rubrica_card_get_next_address(RUBRICA_CARD(card)))
    {
      if (IS_RUBRICA_ADDRESS(data))
	{
	  xmlNodePtr adsxml;      /* address node, addresses's child  */
	  xmlNodePtr node;        /* address's child  */
	  gchar *type, *street, *number, *city, *zip;
	  gchar *province, *state, *country;

	  rubrica_address_get(RUBRICA_ADDRESS(data), &type, &street, &number, 
			      &city, &zip, &province, &state, &country);

	  adsxml = xmlNewTextChild(addressxml, NULL, "Address", NULL);

	  rubrica_io_set_str(adsxml, "type", type);

	  node = xmlNewTextChild(adsxml, NULL, "Street", (xmlChar*) street);
	  rubrica_io_set_str(node, "number", number);

	  node = xmlNewTextChild(adsxml, NULL, "City", (xmlChar*) city);
	  rubrica_io_set_str(node, "zip", zip);

	  xmlNewTextChild(adsxml, NULL, "Province", (xmlChar*) province);
	  xmlNewTextChild(adsxml, NULL, "State",    (xmlChar*) state);
	  xmlNewTextChild(adsxml, NULL, "Country",  (xmlChar*) country);
	}
    }


  /* NetAddresses
   */
  netxml = xmlNewTextChild(cardxml, NULL, "Net", NULL);
  data = rubrica_card_get_net_address(RUBRICA_CARD(card));
  for (; data; data = rubrica_card_get_next_net_address(RUBRICA_CARD(card)))
    if (IS_RUBRICA_NET_ADDRESS(data))
      {
	xmlNodePtr uri;
	gchar *tmp; 

	tmp = rubrica_net_address_get_url(RUBRICA_NET_ADDRESS(data));
	uri = xmlNewTextChild(netxml, NULL, "Uri", (xmlChar*) tmp);
	
	tmp  = rubrica_net_address_get_url_type(RUBRICA_NET_ADDRESS(data));
	rubrica_io_set_str(uri, "type", tmp);
      }
  

  /* Telephone numbers
  */
  telxml = xmlNewTextChild(cardxml, NULL, "TelephoneNumbers", NULL);
  data = rubrica_card_get_telephone(RUBRICA_CARD(card));
  for (; data; data = rubrica_card_get_next_telephone(RUBRICA_CARD(card)))
    if (IS_RUBRICA_TELEPHONE(data))
      {
	xmlNodePtr tel;
	gchar *tmp; 

	tmp = rubrica_telephone_get_number(RUBRICA_TELEPHONE(data));
	tel = xmlNewTextChild(telxml, NULL, "Telephone", (xmlChar*) tmp);
	
	tmp = rubrica_telephone_get_tel_type(RUBRICA_TELEPHONE(data));
	rubrica_io_set_str(tel, "type", tmp);
      }
}


void
rubrica_save_write_personal_data(xmlNodePtr xmlnode, RubricaPersonalCard *card)
{
  gpointer data;

  data = rubrica_personal_card_get_contact(RUBRICA_PERSONAL_CARD(card));
  if (IS_RUBRICA_CONTACT(data))
    {
      xmlNodePtr contact;
      xmlNodePtr node;  
      gboolean bool;
      gchar *first, *middle, *last, *nick;
      gchar *prof, *prefix, *title, *photo;
      gchar *day, *month, *year; 
      
      rubrica_contact_get(RUBRICA_CONTACT(data), &first, &middle, &last, &nick,
			  &prof, &prefix, &title, &photo, &day, &month, &year);
      
      contact = xmlNewTextChild(xmlnode, NULL, "Data", NULL);

      xmlNewTextChild(contact, NULL, "FirstName",  first);
      xmlNewTextChild(contact, NULL, "MiddleName", middle);
      xmlNewTextChild(contact, NULL, "LastName",   last);
      xmlNewTextChild(contact, NULL, "NickName",   nick);
      xmlNewTextChild(contact, NULL, "Profession", prof);
      xmlNewTextChild(contact, NULL, "NamePrefix", prefix);
      xmlNewTextChild(contact, NULL, "Title",      title);

      node = xmlNewTextChild(contact, NULL, "Photo", photo);
      rubrica_io_set_str(node, "type", "url");
      
      node = xmlNewTextChild(contact, NULL, "Birthday", NULL);
      bool = (g_ascii_strcasecmp(day, "BadDay") == 0);
      rubrica_io_set_bool(node, "known", bool);     
      rubrica_io_set_str (node, "day",   day);
      rubrica_io_set_str (node, "month", month);
      rubrica_io_set_str (node, "year",  year); 
    }
  
  data = rubrica_personal_card_get_work(RUBRICA_PERSONAL_CARD(card));
  if (IS_RUBRICA_WORK(data))
    {     
      xmlNodePtr work;
      gchar *assigment, *org, *dep, *subdep;
      gchar *manager, *mphone, *collaborator, *cphone;
      
      rubrica_work_get(RUBRICA_WORK(data), 
		       &assigment, &org, &dep, &subdep, 
		       &manager, &mphone, &collaborator, &cphone);

      work = xmlNewTextChild(xmlnode, NULL, "Work", NULL);
       
      xmlNewTextChild(work, NULL, "Assigment",         assigment);
      xmlNewTextChild(work, NULL, "Organization",      org);
      xmlNewTextChild(work, NULL, "Department",        dep);
      xmlNewTextChild(work, NULL, "SubDepartment",     subdep);
      xmlNewTextChild(work, NULL, "ManagerName",       manager);
      xmlNewTextChild(work, NULL, "ManagerPhone",      mphone);
      xmlNewTextChild(work, NULL, "CollaboratorName",  collaborator);
      xmlNewTextChild(work, NULL, "CollaboratorPhone", cphone);
    }
  
  data = rubrica_personal_card_get_notes(RUBRICA_PERSONAL_CARD(card));
  if (IS_RUBRICA_NOTES(data))
    {
      xmlNodePtr notes;
      xmlNodePtr node;

      gboolean married, birth, anniversary;
      gchar *spouse, *children, *note, *pkey;
      gchar *bday, *bmonth, *byear;
      gchar *aday, *amonth, *ayear;

      rubrica_notes_get(RUBRICA_NOTES(data), 
			&married, &birth, &anniversary,
			&spouse, &children, &note, &pkey,
			&bday, &bmonth, &byear,
 			&aday, &amonth, &ayear);

      notes = xmlNewTextChild(xmlnode, NULL, "Notes", NULL);

      rubrica_io_set_bool(notes, "married", married);
      
      xmlNewTextChild(notes, NULL, "SpouseName", spouse);
      xmlNewTextChild(notes, NULL, "Child",      children);
      xmlNewTextChild(notes, NULL, "OtherNotes", note);
      xmlNewTextChild(notes, NULL, "PublicKey",  pkey);

      node = xmlNewTextChild(notes, NULL, "SpouseBirthday", NULL);
      rubrica_io_set_bool(node, "known", birth);
      rubrica_io_set_str (node, "day",   bday);
      rubrica_io_set_str (node, "month", bmonth);
      rubrica_io_set_str (node, "year",  byear);

      node = xmlNewTextChild(notes, NULL, "Anniversary", NULL);
      rubrica_io_set_bool(node, "known", anniversary);
      rubrica_io_set_str (node, "day",   aday);
      rubrica_io_set_str (node, "month", amonth);
      rubrica_io_set_str (node, "year",  ayear);
    }
}


void
rubrica_save_write_company_data(xmlNodePtr xmlnode, RubricaCompanyCard *card)
{
  xmlNodePtr company;
  gpointer data;
  gchar *name, *pi, *notes;
  
  rubrica_company_card_get(RUBRICA_COMPANY_CARD(card), &name, &pi, &notes);
  
  company = xmlNewTextChild(xmlnode, NULL, "Company", NULL);
  xmlNewTextChild(company, NULL, "CompanyName", name);
  xmlNewTextChild(company, NULL, "Pi",          pi);
  xmlNewTextChild(company, NULL, "Notes",       notes);
  
  data = rubrica_company_card_get_ref(RUBRICA_COMPANY_CARD(card));
  for (; data; data = rubrica_company_card_get_next_ref(card))
    {
      xmlNodePtr xmlref;
      gchar *refid, *info;

      refid = rubrica_ref_get_id(RUBRICA_REF(data));
      info  = rubrica_ref_get_info(RUBRICA_REF(data));

      xmlref = xmlNewTextChild(company, NULL, "Refs", info);
      rubrica_io_set_str(xmlref, "refid", refid);      
    }
}







