/*
*  RAL -- Rubrica Addressbook Library
*  file: vcard.h
*  
*  Copyright (C) Nicola Fragale <nicolafragale@libero.it>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#ifndef _RUBRICA_VCARD_H
#define _RUBRICA_VCARD_H

#include <stdio.h>
#include <glib.h>
#include <glib-object.h>

#define RUBRICA_VCARD_TYPE            (rubrica_vcard_get_type())
#define RUBRICA_VCARD(obj)            (G_TYPE_CHECK_INSTANCE_CAST((obj),      \
                                       RUBRICA_VCARD_TYPE, RubricaVCard))
#define RUBRICA_VCARD_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST((klass),       \
                                       RUBRICA_VCARD_TYPE, RubricaVCardClass))
#define IS_RUBRICA_VCARD(obj)         (G_TYPE_CHECK_INSTANCE_TYPE((obj),      \
                                       RUBRICA_VCARD_TYPE))
#define IS_RUBRICA_VCARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE((klass),       \
                                       RUBRICA_VCARD_TYPE))
#define RUBRICA_VCARD_GET_CLASS(obj)  (G_TYPE_CHECK_INSTANCE_GET_CLASS((obj), \
                                       RUBRICA_VCARD_TYPE, RubricaVCardClass))


typedef struct _RubricaVCard          RubricaVCard;
typedef struct _RubricaVCardClass     RubricaVCardClass;
typedef struct _RubricaVCardPrivate   RubricaVCardPrivate;


/* error code returned by rubrica_vcard_open_file 
*/
enum {
  RUBRICA_VCARD_FILE_OPEN_SUCCESS,
  RUBRICA_VCARD_FILE_OPEN_FAIL,
  RUBRICA_VCARD_FILE_IMPORT_SUCCESS
};


typedef enum {
  EVOLUTION_EXT = 0,   /* TO DO */
  KADDRBOOK_EXT,       /* seem work */
  RUBRICA_EXT,         /* seem work */      
  VCARD_EXT,           /* seem work */ 
  BAD_EXT
} RubricaVCardExt;


struct _RubricaVCard 
{
  GObject parent;
  
  FILE* fp;               /* the vcard file */

  /* private */
  RubricaVCardPrivate* private;
};

struct _RubricaVCardClass
{
  GObjectClass parent;
  
  /* signals */
  void (*file_opened)         (RubricaVCard*, gpointer error);
  void (*card_decoded)        (RubricaVCard*, gpointer card);
  void (*addressbook_decoded) (RubricaVCard*);
};


/*
  signals:
  vcard_file_opened            -- emitted when a vcard file has been opened
                                  (whith error code on error or success)
  vcard_card_decoded           -- emitted when a card has been read
  vcard_addressbook_decoded    -- emitted when vcard addressbook has been read
*/



GType         rubrica_vcard_get_type   (void);


/* ************ Public ************
*/

RubricaVCard* rubrica_vcard_new          (void);
gint          rubrica_vcard_open_file    (RubricaVCard* vcard, 
					  gchar* filename);

void          rubrica_vcard_free_vcard   (RubricaVCard *vcard);


#endif
