/*
*  RAL -- Rubrica Addressbook Library
*  file: work.h
*  
*  Copyright (C) Nicola Fragale <nicolafragale@libero.it>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#ifndef _RUBRICA_WORK_H
#define _RUBRICA_WORK_H

#include <glib.h>
#include <glib-object.h>


#define RUBRICA_WORK_TYPE            (rubrica_work_get_type())

#define RUBRICA_WORK(obj)            (G_TYPE_CHECK_INSTANCE_CAST((obj), \
                                      RUBRICA_WORK_TYPE,           \
                                      RubricaWork))

#define RUBRICA_WORK_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST((klass),  \
                                      RUBRICA_WORK_TYPE,           \
                                      RubricaWorkClass))

#define IS_RUBRICA_WORK(obj)         (G_TYPE_CHECK_INSTANCE_TYPE((obj), \
                                      RUBRICA_WORK_TYPE))

#define IS_RUBRICA_WORK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE((klass),  \
                                      RUBRICA_WORK_TYPE))

#define RUBRICA_WORK_GET_CLASS(klass) (G_TYPE_INSTANCE_GET_CLASS((klass),\
                                       RUBRICA_WORK_TYPE,           \
                                       RubricaWorkClass))


typedef struct _RubricaWork        RubricaWork;
typedef struct _RubricaWorkClass   RubricaWorkClass;
typedef struct _RubricaWorkPrivate RubricaWorkPrivate;


struct _RubricaWork
{
  GObject parent; 

  gchar* assigment;             /* contact role             */
  gchar* org;                   /* organization             */
  gchar* dep;                   /* department               */
  gchar* subdep;                /* sub department           */
  gchar* manager;               /* contact's manager        */
  gchar* mphone;                /* manager telephone        */
  gchar* collaborator;          /* contact's collaborator   */
  gchar* cphone;                /* collaborator's telephone */
  
  RubricaWorkPrivate* private;
};


struct _RubricaWorkClass
{
  GObjectClass parent_class;
};


GType            rubrica_work_get_type (void);
 

RubricaWork* rubrica_work_new  (void);
void         rubrica_work_free (RubricaWork* work);

RubricaWork* rubrica_work_copy (RubricaWork* work);


void   rubrica_work_set               (RubricaWork* work, gchar* assigment,
				       gchar* org, gchar* dep, gchar* subdep,
				       gchar* manager, gchar* mtelephone,
				       gchar* collaborator, gchar* ctelephone);

void   rubrica_work_set_assigment     (RubricaWork* work, gchar* str);
void   rubrica_work_set_organization  (RubricaWork* work, gchar* str);
void   rubrica_work_set_department    (RubricaWork* work, gchar* str);
void   rubrica_work_set_subdepartment (RubricaWork* work, gchar* str);
void   rubrica_work_set_manager       (RubricaWork* work, gchar* str);
void   rubrica_work_set_mtelephone    (RubricaWork* work, gchar* str);
void   rubrica_work_set_collaborator  (RubricaWork* work, gchar* str);
void   rubrica_work_set_ctelephone    (RubricaWork* work, gchar* str);


void   rubrica_work_get               (RubricaWork* work, 
				       gchar** assigment, gchar** org, 
				       gchar** dep, gchar** subdep, 
				       gchar** man, gchar** mtel,
				       gchar** col, gchar** ctel);

gchar* rubrica_work_get_assigment     (RubricaWork* work);
gchar* rubrica_work_get_organization  (RubricaWork* work);
gchar* rubrica_work_get_department    (RubricaWork* work);
gchar* rubrica_work_get_subdepartment (RubricaWork* work);
gchar* rubrica_work_get_manager       (RubricaWork* work);
gchar* rubrica_work_get_mtelephone    (RubricaWork* work);
gchar* rubrica_work_get_collaborator  (RubricaWork* work);
gchar* rubrica_work_get_ctelephone    (RubricaWork* work);

#endif
