#include <stdlib.h>
#include <glib.h>
#include <glib-object.h>

#include <libral.h>


void 
open_abook_fail(RubricaAbook* abook, RubricaError err, gpointer user_data)
{
  g_return_if_fail(IS_RUBRICA_ABOOK(abook));

  g_print("\n%s", (gchar*) user_data);
  g_print("\nError: %d", err);
}


void item_read(RubricaAbook* abook, gpointer card, gpointer user_data)
{
  g_return_if_fail(IS_RUBRICA_ABOOK(abook));
  
  g_print("\nScheda letta: %s", 
	  rubrica_card_get_card_name(RUBRICA_CARD(card)));
  rubrica_card_print(RUBRICA_CARD(card));
}


void abook_addressbook_read(RubricaAbook* abook, gpointer user_data)
{
  g_return_if_fail(IS_RUBRICA_ABOOK(abook));

  g_print("\nRubrica letta");
}


int 
main(int argc, char* argv[])
{
  RubricaAbook* abook;
  char* file;

  g_type_init();
  
  abook = rubrica_abook_new();

  g_signal_connect(G_OBJECT (abook), "open_fail",
		   (GCallback) open_abook_fail, "Apertura fallita");

  g_signal_connect(G_OBJECT (abook), "card_read",
		   (GCallback) item_read, NULL);

  g_signal_connect(G_OBJECT (abook), "addressbook_read",
		   (GCallback) abook_addressbook_read, NULL);

  if (argv[1])
    file = g_strdup(argv[1]);
  else
    {
      g_print("\nSyntax: abook file.abook\n");
      return -1;
    }

  rubrica_abook_open_file(abook, file);
  g_print("\n\nAddress book name: %s\nAddress book path: %s"
	  "\nItems in address book: %d", 
	  rubrica_abook_get_name(abook),
	  rubrica_abook_get_path(abook),
	  rubrica_abook_get_items(abook));

  rubrica_abook_free(abook);

  g_print("\n\n******  No errors...");
  g_free(file);

  return 0;
}


